package com.bonus.zlpt.equip.mapper;

import java.util.List;



import com.bonus.zlpt.common.core.domain.system.SysFile;
import com.bonus.zlpt.equip.api.domain.DevInfo;
import com.bonus.zlpt.equip.api.domain.dto.InforMationDto;
import com.bonus.zlpt.equip.api.domain.vo.DevInfoVo;

/**
 * 设备信息Mapper接口
 * 
 * @author xsheng
 * @date 2023-12-02
 */
public interface DevInfoMapper 
{
    /**
     * 查询设备信息
     * 
     * @param maId 设备信息主键
     * @return 设备信息
     */
    public DevInfoVo selectDevInfoByMaId(Long maId);

    /**
     * 查询设备图片集
     *
     * @param maId 设备信息主键
     * @return 设备图片集
     */
    public List<SysFile> getFilesByMaId(Long maId);

    public Long getCompanyUpNum(Long ownCo);

    /**
     * 查询设备信息列表
     * 
     * @param devInfo 设备信息
     * @return 设备信息集合
     */
    public List<DevInfoVo> selectDevInfoList(DevInfo devInfo);

    public List<DevInfoVo> selectDevInfoHotList(DevInfo devInfo);

    /**
     * 新增设备信息
     * 
     * @param devInfo 设备信息
     * @return 结果
     */
    public int insertDevInfo(DevInfo devInfo);

    /**
     * 修改设备信息
     * 
     * @param devInfo 设备信息
     * @return 结果
     */
    public int updateDevInfo(DevInfo devInfo);

    /**
     * 删除设备信息
     * 
     * @param maId 设备信息主键
     * @return 结果
     */
    public int deleteDevInfoByMaId(Long maId);

    /**
     * 批量删除设备信息
     * 
     * @param maIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDevInfoByMaIds(Long[] maIds);

    /**
     * 添加经纬度信息
     * @param inforMationDto
     * @return
     */
    int insertLon(InforMationDto inforMationDto);
}
